==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/cs_CZ.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Úložiště není dostupné",
    "Storage invalid" : "Neplatné úložiště",
    "Unknown error" : "Neznámá chyba",
    "Could not move %s - File with this name already exists" : "Nelze přesunout %s - již existuje soubor se stejným názvem",
    "Could not move %s" : "Nelze přesunout %s",
    "Permission denied" : "Přístup odepřen",
    "The target folder has been moved or deleted." : "Cílová složka byla přesunuta nebo smazána.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Název %s ve složce %s již existuje. Vyberte prosím jiné jméno.",
    "Error when creating the file" : "Chyba při vytváření souboru",
    "Error when creating the folder" : "Chyba při vytváření složky",
    "Unable to set upload directory." : "Nelze nastavit adresář pro nahrané soubory.",
    "Invalid Token" : "Neplatný token",
    "No file was uploaded. Unknown error" : "Žádný soubor nebyl odeslán. Neznámá chyba",
    "There is no error, the file uploaded with success" : "Soubor byl odeslán úspěšně",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Odesílaný soubor přesahuje velikost upload_max_filesize povolenou v php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Odeslaný soubor přesáhl svou velikostí parametr MAX_FILE_SIZE specifikovaný ve formuláři HTML",
    "The uploaded file was only partially uploaded" : "Soubor byl odeslán pouze částečně",
    "No file was uploaded" : "Žádný soubor nebyl odeslán",
    "Missing a temporary folder" : "Chybí adresář pro dočasné soubory",
    "Failed to write to disk" : "Zápis na disk selhal",
    "Not enough storage available" : "Nedostatek dostupného úložného prostoru",
    "Upload failed. Could not find uploaded file" : "Nahrávání selhalo. Nepodařilo se nalézt nahraný soubor.",
    "Upload failed. Could not get file info." : "Nahrávání selhalo. Nepodařilo se získat informace o souboru.",
    "Invalid directory." : "Neplatný adresář",
    "Files" : "Soubory",
    "All files" : "Všechny soubory",
    "Favorites" : "Oblíbené",
    "Home" : "Domů",
    "Close" : "Zavřít",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nelze nahrát soubor {filename}, protože je to buď adresář nebo má velikost 0 bytů",
    "Total file size {size1} exceeds upload limit {size2}" : "Celková velikost souboru {size1} překračuje povolenou velikost pro nahrávání {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Není dostatek místa pro uložení, velikost souboru je {size1}, zbývá pouze {size2}",
    "Upload cancelled." : "Odesílání zrušeno.",
    "Could not get result from server." : "Nepodařilo se získat výsledek ze serveru.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Probíhá odesílání souboru. Opuštění stránky způsobí zrušení nahrávání.",
    "Actions" : "Činnosti",
    "Download" : "Stáhnout",
    "Rename" : "Přejmenovat",
    "Delete" : "Smazat",
    "Details" : "Podrobnosti",
    "Select" : "Vybrat",
    "Pending" : "Nevyřízené",
    "Unable to determine date" : "Nelze určit datum",
    "This operation is forbidden" : "Tato operace je zakázána",
    "This directory is unavailable, please check the logs or contact the administrator" : "Tento adresář není dostupný, zkontrolujte prosím logy nebo kontaktujte svého správce systému",
    "Error moving file." : "Chyba při přesunu souboru.",
    "Error moving file" : "Chyba při přesunu souboru",
    "Error" : "Chyba",
    "{new_name} already exists" : "{new_name} již existuje",
    "Could not rename file" : "Nepodařilo se přejmenovat soubor",
    "Could not create file" : "Nepodařilo se vytvořit soubor",
    "Could not create folder" : "Nepodařilo se vytvořit složku",
    "Error deleting file." : "Chyba při mazání souboru.",
    "No entries in this folder match '{filter}'" : "V tomto adresáři nic nesouhlasí s '{filter}'",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Upraveno",
    "_%n folder_::_%n folders_" : ["%n složka","%n složky","%n složek"],
    "_%n file_::_%n files_" : ["%n soubor","%n soubory","%n souborů"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo vytvářet soubory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávám %n soubor","Nahrávám %n soubory","Nahrávám %n souborů"],
    "New" : "Nový",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatným názvem souboru.",
    "File name cannot be empty." : "Název souboru nemůže být prázdný řetězec.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložiště uživatele {owner} je zaplněné, soubory nelze aktualizovat a synchronizovat!",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložiště je plné, nelze aktualizovat ani synchronizovat soubory.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úložiště uživatele {owner} je téměř plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložiště je téměř plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["odpovídá '{filter}'","odpovídá '{filter}'","odpovídá '{filter}'"],
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů"],
    "Favorited" : "Přidáno k oblíbeným",
    "Favorite" : "Oblíbené",
    "{newname} already exists" : "{newname} již existuje",
    "Upload" : "Odeslat",
    "Text file" : "Textový soubor",
    "New text file.txt" : "Nový textový soubor.txt",
    "Folder" : "Složka",
    "New folder" : "Nová složka",
    "An error occurred while trying to update the tags" : "Při pokusu o úpravu tagů nastala chyba",
    "A new file or folder has been <strong>created</strong>" : "Byl <strong>vytvořen</strong> nový soubor nebo složka",
    "A file or folder has been <strong>changed</strong>" : "Soubor nebo složka byla <strong>změněna</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit oznámení o tvorbě a změnách vašich <strong>oblíbených souborů</strong> <em>(Pouze streamovat)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Soubor nebo složka byla <strong>smazána</strong>",
    "A file or folder has been <strong>restored</strong>" : "Soubor nebo složka byla <strong>obnovena</strong>",
    "You created %1$s" : "Vytvořili jste %1$s",
    "%2$s created %1$s" : "%2$s vytvořil(a) %1$s",
    "%1$s was created in a public folder" : "%1$s byl vytvořen ve veřejném adresáři",
    "You changed %1$s" : "Změnili jste %1$s",
    "%2$s changed %1$s" : "%2$s změnil(a) %1$s",
    "You deleted %1$s" : "Smazali jste %1$s",
    "%2$s deleted %1$s" : "%2$s smazal(a) %1$s",
    "You restored %1$s" : "Obnovili jste %1$s",
    "%2$s restored %1$s" : "%2$s obnovil(a) %1$s",
    "Changed by %2$s" : "Změněno uživatelem %2$s",
    "Deleted by %2$s" : "Smazáno uživatelem %2$s",
    "Restored by %2$s" : "Obnoveno uživatelem %2$s",
    "%s could not be renamed as it has been deleted" : "%s nelze přejmenovat, protože byl smazán",
    "%s could not be renamed" : "%s nemůže být přejmenován",
    "Upload (max. %s)" : "Nahrát (max. %s)",
    "File handling" : "Zacházení se soubory",
    "Maximum upload size" : "Maximální velikost pro odesílání",
    "max. possible: " : "největší možná: ",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "Při použití PHP-FPM může změna tohoto nastavení trvat až 5 minut po jeho uložení.",
    "Save" : "Uložit",
    "Can not be edited from here due to insufficient permissions." : "Nelze odsud upravovat z důvodu nedostatečných oprávnění.",
    "Settings" : "Nastavení",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Použijte tuto adresu pro <a href=\"%s\" target=\"_blank\">přístup k vašim souborům přes WebDAV</a>",
    "Cancel upload" : "Zrušit odesílání",
    "No files in here" : "Žádné soubory",
    "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo synchronizujte se svými přístroji!",
    "No entries found in this folder" : "V této složce nebylo nic nalezeno",
    "Select all" : "Vybrat vše",
    "Upload too large" : "Odesílaný soubor je příliš velký",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Soubory, které se snažíte odeslat, překračují limit velikosti odesílání na tomto serveru.",
    "Files are being scanned, please wait." : "Soubory se prohledávají, prosím čekejte.",
    "Currently scanning" : "Prohledává se",
    "No favorites" : "Žádné oblíbené",
    "Files and folders you mark as favorite will show up here" : "Soubory a adresáře označené jako oblíbené budou zobrazeny zde"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/cs_CZ.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Úložiště není dostupné",
    "Storage invalid" : "Neplatné úložiště",
    "Unknown error" : "Neznámá chyba",
    "Unable to set upload directory." : "Nelze nastavit adresář pro nahrané soubory.",
    "Invalid Token" : "Neplatný token",
    "No file was uploaded. Unknown error" : "Žádný soubor nebyl odeslán. Neznámá chyba",
    "There is no error, the file uploaded with success" : "Soubor byl odeslán úspěšně",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Odesílaný soubor přesahuje velikost upload_max_filesize povolenou v php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Odeslaný soubor přesáhl svou velikostí parametr MAX_FILE_SIZE specifikovaný ve formuláři HTML",
    "The uploaded file was only partially uploaded" : "Soubor byl odeslán pouze částečně",
    "No file was uploaded" : "Žádný soubor nebyl odeslán",
    "Missing a temporary folder" : "Chybí adresář pro dočasné soubory",
    "Failed to write to disk" : "Zápis na disk selhal",
    "Not enough storage available" : "Nedostatek dostupného úložného prostoru",
    "The target folder has been moved or deleted." : "Cílová složka byla přesunuta nebo smazána.",
    "Upload failed. Could not find uploaded file" : "Nahrávání selhalo. Nepodařilo se nalézt nahraný soubor.",
    "Upload failed. Could not get file info." : "Nahrávání selhalo. Nepodařilo se získat informace o souboru.",
    "Invalid directory." : "Neplatný adresář",
    "Files" : "Soubory",
    "All files" : "Všechny soubory",
    "Favorites" : "Oblíbené",
    "Home" : "Domů",
    "Close" : "Zavřít",
    "Upload cancelled." : "Odesílání zrušeno.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nelze nahrát soubor {filename}, protože je to buď adresář nebo má velikost 0 bytů",
    "Total file size {size1} exceeds upload limit {size2}" : "Celková velikost souboru {size1} překračuje povolenou velikost pro nahrávání {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Není dostatek místa pro uložení, velikost souboru je {size1}, zbývá pouze {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Chyba nahrávání souboru \"{fileName}\": {message}",
    "Could not get result from server." : "Nepodařilo se získat výsledek ze serveru.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Probíhá odesílání souboru. Opuštění stránky způsobí zrušení nahrávání.",
    "Actions" : "Činnosti",
    "Download" : "Stáhnout",
    "Rename" : "Přejmenovat",
    "Delete" : "Smazat",
    "Disconnect storage" : "Odpojit úložiště",
    "Unshare" : "Zrušit sdílení",
    "Details" : "Podrobnosti",
    "Select" : "Vybrat",
    "Pending" : "Nevyřízené",
    "Unable to determine date" : "Nelze určit datum",
    "This operation is forbidden" : "Tato operace je zakázána",
    "This directory is unavailable, please check the logs or contact the administrator" : "Tento adresář není dostupný, zkontrolujte prosím logy nebo kontaktujte svého správce systému",
    "Could not move \"{file}\", target exists" : "Nelze přesunout \"{file}\", cíl existuje",
    "Could not move \"{file}\"" : "Nelze přesunout \"{file}\"",
    "{newName} already exists" : "{newName} již existuje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nelze přejmenovat \"{fileName}\", již neexistuje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Jméno \"{targetName}\" je již použito v adresáři \"{dir}\". Vyberte prosím jiné jméno.",
    "Could not rename \"{fileName}\"" : "Nelze přejmenovat \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nelze vytvořit soubor \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nelze vytvořit soubor \"{file}\", protože již existuje",
    "Could not create folder \"{dir}\"" : "Nelze vytvořit adresář \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "Nelze vytvořit adresář \"{dir}\", protože již existuje",
    "Error deleting file \"{fileName}\"." : "Chyba mazání souboru \"{fileName}\".",
    "No entries in this folder match '{filter}'" : "V tomto adresáři nic nesouhlasí s '{filter}'",
    "Name" : "Název",
    "Size" : "Velikost",
    "Modified" : "Upraveno",
    "_%n folder_::_%n folders_" : ["%n složka","%n složky","%n složek"],
    "_%n file_::_%n files_" : ["%n soubor","%n soubory","%n souborů"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "You don’t have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo vytvářet soubory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávám %n soubor","Nahrávám %n soubory","Nahrávám %n souborů"],
    "New" : "Nový",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatným názvem souboru.",
    "File name cannot be empty." : "Název souboru nemůže být prázdný řetězec.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Úložiště uživatele {owner} je zaplněné, soubory nelze aktualizovat a synchronizovat!",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložiště je plné, nelze aktualizovat ani synchronizovat soubory.",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Úložiště uživatele {owner} je téměř plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Vaše úložiště je téměř plné ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["odpovídá '{filter}'","odpovídá '{filter}'","odpovídá '{filter}'"],
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů"],
    "Favorited" : "Přidáno k oblíbeným",
    "Favorite" : "Oblíbené",
    "Folder" : "Složka",
    "New folder" : "Nová složka",
    "{newname} already exists" : "{newname} již existuje",
    "Upload" : "Odeslat",
    "An error occurred while trying to update the tags" : "Při pokusu o úpravu tagů nastala chyba",
    "A new file or folder has been <strong>created</strong>" : "Byl <strong>vytvořen</strong> nový soubor nebo složka",
    "A file or folder has been <strong>changed</strong>" : "Soubor nebo složka byla <strong>změněna</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limit oznámení o tvorbě a změnách vašich <strong>oblíbených souborů</strong> <em>(Pouze streamovat)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Soubor nebo složka byla <strong>smazána</strong>",
    "A file or folder has been <strong>restored</strong>" : "Soubor nebo složka byla <strong>obnovena</strong>",
    "You created %1$s" : "Vytvořili jste %1$s",
    "%2$s created %1$s" : "%2$s vytvořil(a) %1$s",
    "%1$s was created in a public folder" : "%1$s byl vytvořen ve veřejném adresáři",
    "You changed %1$s" : "Změnili jste %1$s",
    "%2$s changed %1$s" : "%2$s změnil(a) %1$s",
    "You deleted %1$s" : "Smazali jste %1$s",
    "%2$s deleted %1$s" : "%2$s smazal(a) %1$s",
    "You restored %1$s" : "Obnovili jste %1$s",
    "%2$s restored %1$s" : "%2$s obnovil(a) %1$s",
    "Changed by %2$s" : "Změněno uživatelem %2$s",
    "Deleted by %2$s" : "Smazáno uživatelem %2$s",
    "Restored by %2$s" : "Obnoveno uživatelem %2$s",
    "Upload (max. %s)" : "Nahrát (max. %s)",
    "File handling" : "Zacházení se soubory",
    "Maximum upload size" : "Maximální velikost pro odesílání",
    "max. possible: " : "největší možná: ",
    "Save" : "Uložit",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Při použití PHP-FPM může změna nastavení trvat až 5 minut od uložení.",
    "Missing permissions to edit from here." : "Pro úpravy v aktuálním náhledu chybí oprávnění.",
    "Settings" : "Nastavení",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Použijte tuto adresu pro <a href=\"%s\" target=\"_blank\">přístup k vašim souborům přes WebDAV</a>",
    "Cancel upload" : "Zrušit odesílání",
    "No files in here" : "Žádné soubory",
    "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo synchronizujte se svými přístroji!",
    "No entries found in this folder" : "V této složce nebylo nic nalezeno",
    "Select all" : "Vybrat vše",
    "Upload too large" : "Odesílaný soubor je příliš velký",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Soubory, které se snažíte odeslat, překračují limit velikosti odesílání na tomto serveru.",
    "No favorites" : "Žádné oblíbené",
    "Files and folders you mark as favorite will show up here" : "Soubory a adresáře označené jako oblíbené budou zobrazeny zde",
    "Text file" : "Textový soubor",
    "New text file.txt" : "Nový textový soubor.txt",
    "Changed by %2$s" : "Změněno uživatelem %2$s",
    "Deleted by %2$s" : "Smazáno uživatelem %2$s",
    "Restored by %2$s" : "Obnoveno uživatelem %2$s",
    "You changed %1$s" : "Změnili jste %1$s",
    "You created %1$s" : "Vytvořili jste %1$s",
    "You deleted %1$s" : "Smazali jste %1$s",
    "You restored %1$s" : "Obnovili jste %1$s"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
